@@ -1,4 +1,3 @@
-// $Id: parent.js,v 1.1.2.22 2010/01/02 06:07:14 markuspetrux Exp $
 
 (function ($) {
 
@@ -117,7 +116,7 @@ Drupal.modalFrame.open = function(options) {
     onOpen: options.onOpen,
     onLoad: options.onLoad,
     onSubmit: options.onSubmit,
-    customDialogOptions: options.customDialogOptions
+    customDialogOptions: options.customDialogOptions || {}
   };
 
   // Create the dialog and related DOM elements.
@@ -137,8 +136,8 @@ Drupal.modalFrame.create = function() {
 
   // Note: We use scrolling="yes" for IE as a workaround to yet another IE bug
   // where the horizontal scrollbar is always rendered, no matter how wide the
-  // iframe element is defined.
-  self.iframe.$element = $('<iframe id="modalframe-element" name="modalframe-element"'+ ($.browser.msie ? ' scrolling="yes"' : '') +'/>');
+  // iframe element is defined. IE also requires a few more non-std properties.
+  self.iframe.$element = $('<iframe id="modalframe-element" name="modalframe-element"'+ ($.browser.msie ? ' scrolling="yes" frameborder="0" allowTransparency="true"' : '') +'/>');
   self.iframe.$container = $('<div id="modalframe-container"/>').append(self.iframe.$element);
   $('body').append(self.iframe.$container);
 
@@ -435,7 +434,10 @@ Drupal.modalFrame.bindChild = function(iFrameWindow, isClosing) {
       // Install a custom resize handler to allow the child window to trigger
       // changes to the modal frame size.
       $(window).unbind(self.eventHandlerName('childResize')).bind(self.eventHandlerName('childResize'), function() {
+        var overflow = $('html', $iFrameDocument).css('overflow');
+        $('html', $iFrameDocument).css('overflow', 'hidden');
         self.iframe.documentSize = {width: $iFrameDocument.width(), height: $iFrameWindow('body').height() + 25};
+        $('html', $iFrameDocument).css('overflow', overflow);
         self.resize();
       });
     }
@@ -494,8 +496,11 @@ Drupal.modalFrame.bindChild = function(iFrameWindow, isClosing) {
           }
         }
         else if (event.keyCode == $.ui.keyCode.ESCAPE) {
-          setTimeout(function() { self.close(false); }, 10);
-          return false;
+          // Checking the closeOnEscape option, if is false then let the child window open
+          if (typeof self.options.customDialogOptions.closeOnEscape == 'undefined' || self.options.customDialogOptions.closeOnEscape) {
+            setTimeout(function() { self.close(false); }, 10);
+            return false;
+          }
         }
       }
     });
@@ -595,7 +600,7 @@ Drupal.modalFrame.sanitizeSize = function(size) {
  * @see http://www.howtocreate.co.uk/fixedPosition.html
  */
 Drupal.modalFrame.fixPosition = function($element, isOpen) {
-  var $window = $(window);
+  var self = this, $window = $(window);
   if ($.browser.msie && parseInt($.browser.version) <= 6) {
     // IE6 does not support position:'fixed'.
     // Lock the window scrollBar instead.
