@@ -1,5 +1,4 @@
 <?php
-// $Id: modalframe-page.tpl.php,v 1.1.2.4 2009/06/19 16:20:04 markuspetrux Exp $
 
 /**
  * @file
@@ -21,11 +20,11 @@
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language; ?>" lang="<?php print $language->language; ?>" dir="<?php print $language->dir; ?>">
 <head>
 <?php print $head; ?>
-<title><?php print (!empty($title) ? strip_tags($title) : $head_title); ?></title>
+<title><?php print (!empty($title) ? $title : $head_title); ?></title>
 <?php print $styles; ?>
 <?php print $scripts; ?>
 </head>
-<body>
+<body class="<?php print $body_classes; ?>">
 <div class="modalframe-page-wrapper">
   <div class="modalframe-page-container clear-block">
     <div class="modalframe-page-content">
